:orphan:

.. _glossary:

========
Glossary
========

.. glossary::

   GDPR
       The General Data Protection Regulation, a regulation from the European
       Union that guarantees residents a set of rights to know and control how
       their personal data (:term:`PII`) is being used.

       This affects developers around the world who provide services to EU
       residents. `Learn more. <https://www.eugdpr.org/>`_

   PII
   Personally Identifiable Information
       Information that can, by itself or in combination with other data, be
       used to identify an individual person.

       Examples would include a username, e-mail address, full name, or even a
       :term:`pseudonymized` hash of an e-mail address.

   Pseudonymized
   Pseudonymization
       A method of taking identifying information about a person and replacing
       it with data that does not directly identify the person by itself, but
       can still be used to identify that person in combination with other
       data.

       An example would be a SHA256 hash of an e-mail address (which hides the
       e-mail address but can still be used to match the person by comparing
       to another hash of that same e-mail address).
